@@ -1,5 +1,5 @@
 /*
- * 	compress.h		(C) 2006, Aurélien Croc (AP²C)
+ * 	    compress.h                (C) 2006-2008, Aurélien Croc (AP²C)
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -15,24 +15,18 @@
  *  Free Software Foundation, Inc.,
  *  59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  *
- *  $Id: compress.h 77 2007-10-14 12:03:14Z ap2c $
- *
+ *  $Id: compress.h 127 2008-01-28 17:52:50Z ap2c $
+ * 
  */
-#ifndef COMPRESS_H_
-#define COMPRESS_H_
+#ifndef _COMPRESS_H_
+#define _COMPRESS_H_
 
-struct BandArray {
-    unsigned char *array;
-    unsigned char *next;
-    unsigned char *prev;
-};
+class Page;
+class Request;
 
-extern int compressBand(struct BandArray *bandArray, unsigned char *inputBand, 
-    unsigned long bandWidth, unsigned long bandHeight);
-extern int calcOccurs(unsigned char *band, unsigned long bandHeight, 
-    unsigned long bandWidth, unsigned long number);
+extern bool compressPage(const Request& request, Page* page);
 
-#endif 
+#endif /* _COMPRESS_H_ */
 
 /* vim: set expandtab tabstop=4 shiftwidth=4 smarttab tw=80 cin enc=utf8: */
 
